# setup.py
from setuptools import setup, find_packages

setup(
    name="number_series",
    version="0.1",
    packages=find_packages(),
    install_requires=[],
    author="koteswarao_s",
    author_email="suraboinavenkatakoteswarao@gmail.com",
    description="A sample package",
    url="https://github.com/yourusername/mypackage",
)
